# Credits

Main Developer: [@octref](https://github.com/octref)

Contributors:
- [@HerringtonDarkholme](https://github.com/HerringtonDarkholme)
- [@sandersn](https://github.com/sandersn)
- [@yoyo930021](https://github.com/yoyo930021)
- [@ktsn](https://github.com/ktsn)
- [@rchl](https://github.com/rchl)
- [@Uninen](https://github.com/Uninen)

Others: https://github.com/vuejs/vetur/graphs/contributors

### Attributions

Vetur is based on Microsoft's [html language service](https://github.com/Microsoft/vscode/tree/master/extensions/html) for VS Code.

Others:
- Logo from [vuejs/vuejs.org](https://github.com/vuejs/vuejs.org)
- Grammar based on [vuejs/vue-syntax-highlight](https://github.com/vuejs/vue-syntax-highlight)
- Sass grammar based on [TheRealSyler/vscode-sass-indented](https://github.com/TheRealSyler/vscode-sass-indented)
- PostCSS grammar based on [hudochenkov/Syntax-highlighting-for-PostCSS](https://github.com/hudochenkov/Syntax-highlighting-for-PostCSS)
- TypeScript/JavaScript based on [TypeScript](https://github.com/microsoft/TypeScript/#readme)
- CSS/SCSS/LESS feature based on [vscode-css-languageservice](https://github.com/microsoft/vscode-css-languageservice)
